==> jc-1.4.0.tar.gz: javax/swing/JToggleButton__24ToggleButtonModel.h <==
// public class javax.swing.JToggleButton$ToggleButtonModel

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 2cc39bbcb234872c javax_swing_DefaultButtonModel
// @dep_class 1d101433c9fe254c javax_swing_JToggleButton__24ToggleButtonModel

// header file dependencies
// @dep_header javax_swing_DefaultButtonModel

#include "javax/swing/DefaultButtonModel.h"

#ifndef _JC_javax_swing_JToggleButton__24ToggleButtonModel_H_
#define _JC_javax_swing_JToggleButton__24ToggleButtonModel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_refs	_jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_refs;
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_nonrefs	_jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_nonrefs;
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$refs	_jc_javax_swing_JToggleButton__24ToggleButtonModel$refs;
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$nonrefs	_jc_javax_swing_JToggleButton__24ToggleButtonModel$nonrefs;
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object	_jc_javax_swing_JToggleButton__24ToggleButtonModel$object;

typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$fields_struct	_jc_javax_swing_JToggleButton__24ToggleButtonModel$fields_struct;
typedef const struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vmethods	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vmethods;
typedef const struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtable	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vtable;
typedef const struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype;

// Class fields structure
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JToggleButton__24ToggleButtonModel$fields_struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$class_fields;

// Constructors
extern void _jc_javax_swing_JToggleButton__24ToggleButtonModel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object *);

// Virtual methods
extern void _jc_javax_swing_JToggleButton__24ToggleButtonModel$method$setPressed$13b6286e9efa3dea(_jc_env *, struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object *, jboolean);

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToggleButton__24ToggleButtonModel$method_info$setPressed$13b6286e9efa3dea;

// Virtual methods structure
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vmethods {
	void	(*setPressed$13b6286e9efa3dea)(_jc_env *, struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object *, jboolean);
};

// Vtable
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_DefaultButtonModel$vmethods	javax_swing_DefaultButtonModel;
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vmethods	javax_swing_JToggleButton__24ToggleButtonModel;
};

// Vtype
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype {
	_jc_type			type;
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$refs {
    _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_refs	javax_swing_JToggleButton__24ToggleButtonModel;
    _jc_javax_swing_DefaultButtonModel$sub_refs	javax_swing_DefaultButtonModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_DefaultButtonModel$sub_nonrefs	javax_swing_DefaultButtonModel;
    _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_nonrefs	javax_swing_JToggleButton__24ToggleButtonModel;
};

// Object instance structure
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object {
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype	*vtype;
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype _jc_javax_swing_JToggleButton__24ToggleButtonModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToggleButton__24ToggleButtonModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToggleButton__24ToggleButtonModel$class_object;

#endif	/* _JC_javax_swing_JToggleButton__24ToggleButtonModel_H_ */

==> jc-1.4.5.tar.gz: javax/swing/JToggleButton__24ToggleButtonModel.h <==
// public class javax.swing.JToggleButton$ToggleButtonModel

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 2cc39bbcb234872c javax_swing_DefaultButtonModel
// @dep_class 1d101433c9fe254c javax_swing_JToggleButton__24ToggleButtonModel

// header file dependencies
// @dep_header javax_swing_DefaultButtonModel

#include "javax/swing/DefaultButtonModel.h"

#ifndef _JC_javax_swing_JToggleButton__24ToggleButtonModel_H_
#define _JC_javax_swing_JToggleButton__24ToggleButtonModel_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_refs	_jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_refs;
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_nonrefs	_jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_nonrefs;
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$refs	_jc_javax_swing_JToggleButton__24ToggleButtonModel$refs;
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$nonrefs	_jc_javax_swing_JToggleButton__24ToggleButtonModel$nonrefs;
typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object	_jc_javax_swing_JToggleButton__24ToggleButtonModel$object;

typedef struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$fields_struct	_jc_javax_swing_JToggleButton__24ToggleButtonModel$fields_struct;
typedef const struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vmethods	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vmethods;
typedef const struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtable	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vtable;
typedef const struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype;

// Class fields structure
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$fields_struct {
	jlong	serialVersionUID;
};
extern _jc_javax_swing_JToggleButton__24ToggleButtonModel$fields_struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$class_fields;

// Constructors
extern void _jc_javax_swing_JToggleButton__24ToggleButtonModel$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_javax_swing_JToggleButton__24ToggleButtonModel$method$setPressed$13b6286e9efa3dea(_jc_env *, struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object *, jboolean) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_javax_swing_JToggleButton__24ToggleButtonModel$method_info$setPressed$13b6286e9efa3dea;

// Virtual methods structure
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vmethods {
	void	(*setPressed$13b6286e9efa3dea)(_jc_env *, struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object *, jboolean) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_javax_swing_DefaultButtonModel$vmethods	javax_swing_DefaultButtonModel;
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vmethods	javax_swing_JToggleButton__24ToggleButtonModel;
};

// Vtype
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype {
	_jc_type			type;
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_refs {
};

// Reference instance fields (object)
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$refs {
    _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_refs	javax_swing_JToggleButton__24ToggleButtonModel;
    _jc_javax_swing_DefaultButtonModel$sub_refs	javax_swing_DefaultButtonModel;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_javax_swing_DefaultButtonModel$sub_nonrefs	javax_swing_DefaultButtonModel;
    _jc_javax_swing_JToggleButton__24ToggleButtonModel$sub_nonrefs	javax_swing_JToggleButton__24ToggleButtonModel;
};

// Object instance structure
struct _jc_javax_swing_JToggleButton__24ToggleButtonModel$object {
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$refs	refs[0];
	_jc_word		lockword;
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype	*vtype;
	_jc_javax_swing_JToggleButton__24ToggleButtonModel$nonrefs	nonrefs;
};

// Type structure
extern _jc_javax_swing_JToggleButton__24ToggleButtonModel$vtype _jc_javax_swing_JToggleButton__24ToggleButtonModel$type;

// Array types class info structures
_JC_DECL_ARRAYS(javax_swing_JToggleButton__24ToggleButtonModel, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_javax_swing_JToggleButton__24ToggleButtonModel$class_object;

#endif	/* _JC_javax_swing_JToggleButton__24ToggleButtonModel_H_ */
